==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/product_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe ProductController do

  before(:each) do
    login_as("admin")
  end

  fixtures :products, :product_displays, :product_images #, :shipping_costs

  it "should get index" do
    get :index, :clear => 'true'
    response.should be_success
    response.should render_template "index"
    session[:product_search_cond].should == nil
  end
  
  describe "GET show" do
    it "should get show" do
      get :show, :id => '1'
      response.should render_template(:show)
      controller.instance_variable_get(:@product).id.should == 1
      controller.instance_variable_get(:@images).length.should == 0
    end
    
    it "商品画像登録済み" do
      get :show, :id => '100001'
      response.should render_template(:show)
      controller.instance_variable_get(:@product).id.should == 100001
      controller.instance_variable_get(:@images).length.should == 2
    end
  end
  
  describe "GET index" do
    it "list no condition" do
      get :index
      flash[:error].should == nil
      response.should be_success
      response.should render_template "index"
    end
  
    it "list with valid condition" do
      get :index, :condition => { }
      flash[:error].should == nil
      response.should be_success
      response.should render_template "index"
    end
  
    # 秋間コメント
    # Product::SearchCondition の下記のようなバリデーションは無くなり、他のspecと
    # 競合しているので、バリデーションは廃止になったと判断しました。
    # validates_numericality_of :min_stock_count
    #
    it "list with invalid condition" do
      pending "min_stock_countは数値限定ではない？要確認"
      get :index, :condition => { :min_stock_count => "noNumeric" }
      puts flash[:error].inspect
      flash[:error].should_not == nil
      response.should be_success
      response.should render_template "index"
    end
  end
  
  describe "POST edit" do
    before(:each) do
      Product.stub!(:image_list).and_return(true)
      ProductCategory.stub!(:find).and_return(true)
      ProductImage.stub!(:find).and_return(true)
    end

    it "edit in error" do
      flash[:product] = Product.find(1)
      post :edit
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product parameters" do
      flash[:product] = nil
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja')}}
      post :edit, :id => 1, :product => {
        :product_code => "1234567890123" ,
        :course_div => "1" ,
        :order_product_name_1 => "BBB" ,
        :order_product_name_2 => "CCC" ,
        :origin => 'JP'
      },
        :product_display => {
        :product_name_1 => "AAA",
      }
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product parameters" do
      flash[:product] = nil
      post :edit, :id => 1
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product_image parameters" do
      flash[:product_image] = ProductImage.new()
      post :edit, :id => 1
      controller.instance_variable_get(:@product).id.should == 1
      controller.instance_variable_get(:@product_image).should_not == nil
      response.should be_success
    end
  end
  
  describe "POST confirm_update" do
    it "no shipping_cost" do
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
      post :confirm_update, :id => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}
      response.should be_success
    end
  
    it "with shipping_cost valid" do
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
      post :confirm_update, :id => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}, :shipping_cost => { :shipping_cost => 3 }
      response.should be_success
    end
  
    # shippinf_costsテーブルは削除されました
    #    it "with shipping_cost invalid" do
    #      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
    #      post :confirm_update, :id => 1, :page => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}, :shipping_cost => { :shipping_cost => 999999999 }
    #      response.should redirect_to( :action => :edit, :id => 1, :page => 1 )
    #    end
  end
  
  describe "POST update" do
    it "update" do
      mock_display = mock_model(ProductDisplay, :attributes= => true, :save! => true,  :locale => 'ja', :product_id => '1')
      session[:product_form] = {:product_displays => {'ja' => mock_display}}
      post :update, :id => 1, :page => 1, :product => {} #, :shipping_cost => { :shipping_cost => 1000 }
      response.should redirect_to(:action => :show, :id => '1', :page => '1')
    end
  end
  
  describe "POST new" do
    before(:each) do
      Product.stub!(:image_list).and_return(true)
      ProductCategory.stub!(:find).and_return(true)
    end
    
    it "load id" do
      flash[:product] = Product.find(1)
      post :new
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
    
    it "new " do
      flash[:product] = nil
      post :new
      response.should be_success
    end
    
    it "new with parameters" do
      flash[:product] = nil
      post :new, :product => {  }
      response.should be_success
    end
  end
  
  describe "POST confirm_create" do
    it "confirm_create" do
      post :confirm_create, :product => {    }, :shipping_cost => { :shipping_cost => 1000 }
      response.should redirect_to( :action => :new )
    end

    it "confirm_create" do
      post :confirm_create, :product => {
        :product_code => "1234567890555",
        :course_div => "1",
        :order_product_name_1 => "AAA",
        :order_product_name_2 => "bBb",
        :origin => 'JP'
      },
        :shipping_cost => { :shipping_cost => '1000' }
      response.should be_success
    end
  end
  
  describe "POST craete" do
    it "create" do
      new_product_hash = {
        'product_code' => "1234567890555",
        'course_div' => "1",
        'order_product_name_1' => "AAA",
        'order_product_name_2' => "bBb",
        'origin' => 'JP'
      }
      mock_product = Product.new(new_product_hash)
      Product.should_receive(:new).with(new_product_hash).and_return(mock_product)
      mock_product.should_receive(:save!)
      mock_product.should_receive(:order_product_name_1).and_return("AAA")

      post(:create,
        :product => {
          :product_code => "1234567890555",
          :course_div => "1",
          :order_product_name_1 => "AAA",
          :order_product_name_2 => "bBb",
          :origin => 'JP'
        },
        :shipping_cost => { :shipping_cost => '1000' })
      response.should redirect_to( :action => :edit, :id => mock_product.id)
    end
  end
  
  describe "DELETE destroy" do
    it "destroy" do
      delete :destroy, :id => 1, :page => 1
      response.should redirect_to( :action => :index, :page => 1 )
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/product_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe ProductController do

  before(:each) do
    login_as("admin")
  end

  fixtures :products, :product_displays, :product_images #, :shipping_costs

  it "should get index" do
    get :index, :clear => 'true'
    response.should be_success
    response.should render_template "index"
    session[:product_search_cond].should == nil
  end
  
  describe "GET show" do
    it "should get show" do
      get :show, :id => '1'
      response.should render_template(:show)
      controller.instance_variable_get(:@product).id.should == 1
      controller.instance_variable_get(:@images).length.should == 0
    end
    
    it "商品画像登録済み" do
      get :show, :id => '100001'
      response.should render_template(:show)
      controller.instance_variable_get(:@product).id.should == 100001
      controller.instance_variable_get(:@images).length.should == 2
    end
  end
  
  describe "GET index" do
    it "list no condition" do
      get :index
      flash[:error].should == nil
      response.should be_success
      response.should render_template "index"
    end
  
    it "list with valid condition" do
      get :index, :condition => { }
      flash[:error].should == nil
      response.should be_success
      response.should render_template "index"
    end
  
    # 秋間コメント
    # Product::SearchCondition の下記のようなバリデーションは無くなり、他のspecと
    # 競合しているので、バリデーションは廃止になったと判断しました。
    # validates_numericality_of :min_stock_count
    #
    it "list with invalid condition" do
      pending "min_stock_countは数値限定ではない？要確認"
      get :index, :condition => { :min_stock_count => "noNumeric" }
      puts flash[:error].inspect
      flash[:error].should_not == nil
      response.should be_success
      response.should render_template "index"
    end
  end
  
  describe "POST edit" do
    before(:each) do
      Product.stub!(:image_list).and_return(true)
      ProductCategory.stub!(:find).and_return(true)
      ProductImage.stub!(:find).and_return(true)
    end

    it "edit in error" do
      flash[:product] = Product.find(1)
      post :edit
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product parameters" do
      flash[:product] = nil
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja')}}
      post :edit, :id => 1, :product => {
        :product_code => "1234567890123" ,
        :course_div => "1" ,
        :order_product_name_1 => "BBB" ,
        :order_product_name_2 => "CCC" ,
        :origin => 'JP'
      },
        :product_display => {
        :product_name_1 => "AAA",
      }
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product parameters" do
      flash[:product] = nil
      post :edit, :id => 1
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
  
    it "edit id with product_image parameters" do
      flash[:product_image] = ProductImage.new()
      post :edit, :id => 1
      controller.instance_variable_get(:@product).id.should == 1
      controller.instance_variable_get(:@product_image).should_not == nil
      response.should be_success
    end
  end
  
  describe "POST confirm_update" do
    it "no shipping_cost" do
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
      post :confirm_update, :id => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}
      response.should be_success
    end
  
    it "with shipping_cost valid" do
      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
      post :confirm_update, :id => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}, :shipping_cost => { :shipping_cost => 3 }
      response.should be_success
    end
  
    # shippinf_costsテーブルは削除されました
    #    it "with shipping_cost invalid" do
    #      session[:product_form] = {:product_displays => {'ja' => ProductDisplay.new(:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1)}}
    #      post :confirm_update, :id => 1, :page => 1, :product => {  }, :product_display => {:product_name_1 => 'AAA', :locale => 'ja', :product_id => 1}, :shipping_cost => { :shipping_cost => 999999999 }
    #      response.should redirect_to( :action => :edit, :id => 1, :page => 1 )
    #    end
  end
  
  describe "POST update" do
    it "update" do
      mock_display = mock_model(ProductDisplay, :attributes= => true, :save! => true,  :locale => 'ja', :product_id => '1')
      session[:product_form] = {:product_displays => {'ja' => mock_display}}
      post :update, :id => 1, :page => 1, :product => {} #, :shipping_cost => { :shipping_cost => 1000 }
      response.should redirect_to(:action => :show, :id => '1', :page => '1')
    end
  end
  
  describe "POST new" do
    before(:each) do
      Product.stub!(:image_list).and_return(true)
      ProductCategory.stub!(:find).and_return(true)
    end
    
    it "load id" do
      flash[:product] = Product.find(1)
      post :new
      controller.instance_variable_get(:@product).id.should == 1
      response.should be_success
    end
    
    it "new " do
      flash[:product] = nil
      post :new
      response.should be_success
    end
    
    it "new with parameters" do
      flash[:product] = nil
      post :new, :product => {  }
      response.should be_success
    end
  end
  
  describe "POST confirm_create" do
    it "confirm_create" do
      post :confirm_create, :product => {    }, :shipping_cost => { :shipping_cost => 1000 }
      response.should redirect_to( :action => :new )
    end

    it "confirm_create" do
      post :confirm_create, :product => {
        :product_code => "1234567890555",
        :course_div => "1",
        :order_product_name_1 => "AAA",
        :order_product_name_2 => "bBb",
        :origin => 'JP'
      },
        :shipping_cost => { :shipping_cost => '1000' }
      response.should be_success
    end
  end
  
  describe "POST craete" do
    it "create" do
      new_product_hash = {
        'product_code' => "1234567890555",
        'course_div' => "1",
        'order_product_name_1' => "AAA",
        'order_product_name_2' => "bBb",
        'origin' => 'JP',
        'detail_url_outside_flg' => '1',
        'detail_url' => 'testtest'
      }
      mock_product = Product.new()
      Product.should_receive(:new).and_return(mock_product)
      mock_product.should_receive(:set_attributes_and_detail_url).with(new_product_hash)
      mock_product.should_receive(:save!)
      mock_product.should_receive(:order_product_name_1).and_return("AAA")

      post(:create,
        :product => {
          :product_code => "1234567890555",
          :course_div => "1",
          :order_product_name_1 => "AAA",
          :order_product_name_2 => "bBb",
          :origin => 'JP',
          :detail_url_outside_flg => '1',
          :detail_url => 'testtest'
        })
      product_id = controller.instance_variable_get(:@product).id
      response.should redirect_to( :action => :edit, :id => product_id)
    end
  end
  
  describe "DELETE destroy" do
    it "destroy" do
      delete :destroy, :id => 1, :page => 1
      response.should redirect_to( :action => :index, :page => 1 )
    end
  end
end
